@@ -38,16 +38,18 @@ MainWindow::MainWindow(QWidget *parent)
     codec_(QTextCodec::codecForLocale()),
     fileModel_(new SongSortFilterModel(this))
 {
-#ifdef Q_WS_MAEMO_5
-    // DBus connection for orientation change
-    QDBusConnection::systemBus().connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
-                                         MCE_DEVICE_ORIENTATION_SIG,
-                                         this,
-                                         SLOT(orientationChanged(QString)));
-#endif
 
     ui->setupUi(this);
 
+#ifdef Q_WS_MAEMO_5
+    // DBus connection for orientation change
+//    QDBusConnection::systemBus().connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+//                                         MCE_DEVICE_ORIENTATION_SIG,
+//                                         this,
+//                                         SLOT(orientationChanged(QString)));
+    setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+#endif
+
     // Some signals and slots together
     connect(ui->action_Quit, SIGNAL(triggered()), qApp, SLOT(quit()));
     connect(ui->actionDisconnect, SIGNAL(triggered()), this, SLOT(onDisconnect()));
@@ -136,15 +138,6 @@ MainWindow::~MainWindow()
 
     saveAppState();
 
-//#ifdef Q_WS_MAEMO_5
-//    if (playlistKineticScroller_) delete playlistKineticScroller_;
-//    if (artistKineticScroller_) delete artistKineticScroller_;
-//    if (albumKineticScroller_) delete albumKineticScroller_;
-//    if (trackKineticScroller_) delete trackKineticScroller_;
-//    if (dirKineticScroller_) delete dirKineticScroller_;
-//    if (fileKineticScroller_) delete fileKineticScroller_;
-//#endif
-
     // Delete downloaded album art if user desires
     if ( delAlbumArtOnExit_ ) {
         bool rm_error = false; // This is quite useless..
@@ -191,40 +184,40 @@ void MainWindow::saveAppState() const {
 //
 // Orientation changing stuff for maemo 5
 //
-#ifdef Q_WS_MAEMO_5
-void MainWindow::setLandscape() {
-    setAttribute(Qt::WA_Maemo5ForceLandscapeOrientation, true);
-}
-void MainWindow::setPortrait() {
-    setAttribute(Qt::WA_Maemo5ForcePortraitOrientation, true);
-}
-void MainWindow::orientationChanged(const QString &newOrientation)
-{
-    if (newOrientation == QLatin1String(MCE_ORIENTATION_PORTRAIT))
-        setPortrait();
-    else
-        setLandscape();
-}
-bool MainWindow::event(QEvent *ev) {
-    switch (ev->type()) {
-    case QEvent::WindowActivate:
-        QDBusConnection::systemBus().call(
-                QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
-                                               MCE_REQUEST_IF,
-                                               MCE_ACCELEROMETER_ENABLE_REQ));
-        break;
-    case QEvent::WindowDeactivate:
-        QDBusConnection::systemBus().call(
-                QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
-                                               MCE_REQUEST_IF,
-                                               MCE_ACCELEROMETER_DISABLE_REQ));
-        break;
-    default:
-        break;
-    }
-    return QWidget::event(ev);
-}
-#endif
+//#ifdef Q_WS_MAEMO_5
+//void MainWindow::setLandscape() {
+//    setAttribute(Qt::WA_Maemo5ForceLandscapeOrientation, true);
+//}
+//void MainWindow::setPortrait() {
+//    setAttribute(Qt::WA_Maemo5ForcePortraitOrientation, true);
+//}
+//void MainWindow::orientationChanged(const QString &newOrientation)
+//{
+//    if (newOrientation == QLatin1String(MCE_ORIENTATION_PORTRAIT))
+//        setPortrait();
+//    else
+//        setLandscape();
+//}
+//bool MainWindow::event(QEvent *ev) {
+//    switch (ev->type()) {
+//    case QEvent::WindowActivate:
+//        QDBusConnection::systemBus().call(
+//                QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
+//                                               MCE_REQUEST_IF,
+//                                               MCE_ACCELEROMETER_ENABLE_REQ));
+//        break;
+//    case QEvent::WindowDeactivate:
+//        QDBusConnection::systemBus().call(
+//                QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
+//                                               MCE_REQUEST_IF,
+//                                               MCE_ACCELEROMETER_DISABLE_REQ));
+//        break;
+//    default:
+//        break;
+//    }
+//    return QWidget::event(ev);
+//}
+//#endif
 
 //
 // Restore size and position of the app
@@ -665,27 +658,6 @@ void MainWindow::setupTables() {
     ui->playlistTableview->horizontalHeader()->show();
 
     ui->fileList->setModel(fileModel_);
-
-//#ifdef Q_WS_MAEMO_5
-//    // Kinetic scrolling
-//    playlistKineticScroller_ = new QAbstractKineticScroller();
-//    playlistKineticScroller_->setWidget(ui->playlistTableview);
-//    artistKineticScroller_ = new QAbstractKineticScroller();
-//    artistKineticScroller_->setWidget(ui->artistList);
-//    albumKineticScroller_ = new QAbstractKineticScroller();
-//    albumKineticScroller_->setWidget(ui->albumList);
-//    trackKineticScroller_ = new QAbstractKineticScroller();
-//    trackKineticScroller_->setWidget(ui->trackList);
-//    dirKineticScroller_ = new QAbstractKineticScroller();
-//    dirKineticScroller_->setWidget(ui->directoryTree);
-//    fileKineticScroller_ = new QAbstractKineticScroller();
-//    fileKineticScroller_->setWidget(ui->fileList);
-//
-//    playlistKineticScroller_->setMode(QAbstractKineticScroller::AutoMode); // auto/push/acceleration
-//    artistKineticScroller_->setMode(QAbstractKineticScroller::AutoMode);
-//    albumKineticScroller_->setMode(QAbstractKineticScroller::AutoMode);
-//    trackKineticScroller_->setMode(QAbstractKineticScroller::AutoMode);
-//#endif
 }
 
 //
