@@ -6,10 +6,9 @@
 
 #ifdef Q_WS_MAEMO_5
 #include <QtMaemo5>
-#include <QtDBus>
-#include <mce/mode-names.h>
-#include <mce/dbus-names.h>
-//#include <QAbstractKineticScroller>
+//#include <QtDBus>
+//#include <mce/mode-names.h>
+//#include <mce/dbus-names.h>
 #endif
 
 #include "songmodel.h"
@@ -24,6 +23,7 @@
 #include "settingsdialog.h"
 #include "scrobbler.h"
 
+
 namespace Ui
 {
     class MainWindow;
@@ -42,20 +42,20 @@ public:
     // Shows message either in statusbar or in maemo style
     void myShowMessage(QString message);
 
-#ifdef Q_WS_MAEMO_5
-    // Orientation change
-    void setPortrait();
-    void setLandscape();
-#endif
+//#ifdef Q_WS_MAEMO_5
+//    // Orientation change
+//    void setPortrait();
+//    void setLandscape();
+//#endif
 
 
 protected:
     // Close to tray
     void closeEvent(QCloseEvent *event);
 
-#ifdef Q_WS_MAEMO_5
-    bool event(QEvent *ev);
-#endif
+//#ifdef Q_WS_MAEMO_5
+//    bool event(QEvent *ev);
+//#endif
 
     /* * * * * * * * * * * * * * * * * * * * * * */
     /* * * * * * * S L O T S * * * * * * * * * * */
@@ -76,9 +76,9 @@ public slots:
 #if !defined (Q_WS_MAEMO_5) && !defined (Q_WS_HILDON)
     void iconActivated(QSystemTrayIcon::ActivationReason reason);
 #endif
-#ifdef Q_WS_MAEMO_5
-    void orientationChanged(const QString &newOrientation);
-#endif
+//#ifdef Q_WS_MAEMO_5
+//    void orientationChanged(const QString &newOrientation);
+//#endif
 
     /* * * * * * * PLAYLIST SLOTS * * * * * * */
     void onDeleteSelectedFromPlaylist();
@@ -163,15 +163,6 @@ private:
     // Enables/disables some widgets etc.
     void activateUi(bool activated);
 
-//#ifdef Q_WS_MAEMO_5
-//    QAbstractKineticScroller *playlistKineticScroller_;
-//    QAbstractKineticScroller *artistKineticScroller_;
-//    QAbstractKineticScroller *albumKineticScroller_;
-//    QAbstractKineticScroller *trackKineticScroller_;
-//    QAbstractKineticScroller *dirKineticScroller_;
-//    QAbstractKineticScroller *fileKineticScroller_;
-//#endif
-
     // Audioscrobbler
     Scrobbler scrobbler_;
 
